@@ -1,4 +1,3 @@
-from dagster import DagsterInvariantViolationError, check
 from dagster_pandas.constraints import (
     CategoricalColumnConstraint,
     ColumnDTypeFnConstraint,
@@ -19,6 +18,8 @@ from pandas.core.dtypes.common import (
     is_string_dtype,
 )
 
+from dagster import DagsterInvariantViolationError, check
+
 PANDAS_NUMERIC_TYPES = {"int64", "float"}
 
 
@@ -338,7 +339,7 @@ class PandasColumn:
     def categorical_column(
         name,
         categories,
-        of_types="object",
+        of_types=frozenset({"category", "object"}),
         non_nullable=False,
         unique=False,
         ignore_missing_vals=False,
